import { FnAjax, useAjax } from "@/Hook/useAjax"
import { ListData } from "@/services/launchAdq"
import { getSysAdcreativeList } from "@/services/launchAdq/creative"
import { PromotedObjectType } from "@/services/launchAdq/enum"
import { Col, Input, Modal, Row, Select } from "antd"
import React, { useCallback, useEffect, useState } from "react"
import TableData from "../TableData"
import tableConfig from "./tableConfig"


interface Props {
    promotedObjectType: string,
    visible?: boolean,
    onClose?: () => void,
    onChange?: (data: any) => void,
    sysAdcreativeId?: number
}
/**
 * 选择创意
 * @returns 
 */
const CreativeModal: React.FC<Props> = (props) => {

    /****************************/
    const { visible, onClose, onChange, sysAdcreativeId, promotedObjectType } = props
    const sysAdcreativeList: FnAjax<ListData<any>|any> = useAjax((params) => getSysAdcreativeList(params),{formatResult:true})
    const [selectedRowKeys, setSelectedRowKeys] = useState<React.Key[]>([])
    const [oldsearchData, setOldsearchData] = useState<any>(null)
    /****************************/

    // 回填
    useEffect(() => {
        if (sysAdcreativeId) {
            setSelectedRowKeys([sysAdcreativeId])
        }
    }, [sysAdcreativeId])

    // 初始获取列表
    useEffect(() => {
        getList({ pageSize: 20, pageNum: 1, promotedObjectType })
    }, [])
    // 获取列表
    const getList = useCallback((arg: { pageSize: number, pageNum: number, adcreativeName?: string, promotedObjectType?: string }) => {
        Object.keys(arg).forEach(key => {
            !arg[key] && delete arg[key]
        })
        if (JSON.stringify(arg) !== JSON.stringify(oldsearchData)) {
            setOldsearchData(arg)
            sysAdcreativeList.run(arg)
        }
    }, [oldsearchData])

    const handleOk = () => {
        onChange && onChange(selectedRowKeys.toString())
    }
    
    return <Modal title={`选择创意`} bodyStyle={{ padding: 0 }} width={1000} visible={visible} onOk={handleOk} onCancel={() => { onClose && onClose() }}>
        <TableData
            hoverable={false}
            columns={tableConfig}
            ajax={sysAdcreativeList}
            dataSource={sysAdcreativeList?.data?.data?.records}
            loading={sysAdcreativeList?.loading}
            scroll={{ y: 400 }}
            total={sysAdcreativeList?.data?.data?.total}
            page={sysAdcreativeList?.data?.data?.current}
            pageSize={sysAdcreativeList?.data?.data?.size}
            rowSelection={{
                type: 'radio',
                selectedRowKeys: selectedRowKeys,
                onChange: (selectedRowKeys: React.Key[]) => {
                    setSelectedRowKeys(selectedRowKeys)
                }
            }}
            leftChild={<>
                <Row gutter={[10, 10]}>
                    <Col>
                        <Input
                            placeholder='创意名称'
                            allowClear
                            onBlur={(e) => {
                                let value = e.target.value
                                getList({ pageNum: 1, pageSize: 20, adcreativeName: value })
                            }}
                            onKeyDownCapture={(e: any) => {
                                let key = e.key
                                if (key === 'Enter') {
                                    let value = e.target.value
                                    getList({ pageNum: 1, pageSize: 20, adcreativeName: value })
                                }
                            }}
                            onChange={(e) => {
                                let value = e.target.value
                                if (!value) {
                                    getList({ pageNum: 1, pageSize: 20, adcreativeName: value })
                                }
                            }}
                        />
                    </Col>
                </Row>
            </>}
            onChange={(props: any) => {
                let { sortData, pagination } = props
                let { current, pageSize } = pagination
                getList({ pageNum: current, pageSize })
            }}
        />
    </Modal>
}

export default React.memo(CreativeModal)