import { useAjax } from "@/Hook/useAjax"
import { getListByCorpAccount } from "@/services/enterpriseWeChat/userMange"
import { PromotedObjectType } from "@/services/launchAdq/enum"
import { getTaskListApi, TaskListProps } from "@/services/launchAdq/taskList"
import { Card, Input, Select, Space } from "antd"
import React, { useEffect, useState } from "react"




const TaskList: React.FC = () => {

    /*************************/
    const [queryForm, setQueryForm] = useState<TaskListProps>({ pageSize: 20, pageNum: 1 })


    const getTaskList = useAjax((params) => getTaskListApi(params), { formatResult: true })
    /*************************/

    useEffect(() => {
        getList()
    }, [queryForm])

    const getList = () => {
        getTaskList.run(queryForm)
    }

    return <Card>
        <Space style={{ marginBottom: 20 }} wrap={true}>
            <Input placeholder="计划名称" value={queryForm?.campaignName} onChange={(e) => setQueryForm({ ...queryForm, campaignName: e.target.value, pageNum: 1 })} />
            <Select
                placeholder="计划类型"
                maxTagCount={1}
                allowClear
                value={queryForm?.campaignType}
                onChange={(e) => { setQueryForm({ ...queryForm, campaignType: e }) }}
            >
                <Select.Option value='CAMPAIGN_TYPE_NORMAL'>普通展示广告</Select.Option>
                <Select.Option value='CAMPAIGN_TYPE_WECHAT_MOMENTS'>微信朋友圈广告</Select.Option>
            </Select>
            <Select style={{ width: 200 }} value={queryForm?.promotedObjectType} placeholder="推广目标" showSearch filterOption={(input: any, option: any) =>
                (option!.children as unknown as string).toLowerCase().includes(input.toLowerCase())
            } onChange={(e) => { setQueryForm({ ...queryForm, promotedObjectType: e }) }}>
                {Object.keys(PromotedObjectType).map(key => {
                    return <Select.Option value={key} key={key}>{PromotedObjectType[key]}</Select.Option>
                })}
            </Select>
        </Space>
        
    </Card>
}

export default React.memo(TaskList)